@@ -318,7 +318,7 @@ def load_command_table(self, _):
         g.custom_command('create', 'create_functionapp', exception_handler=ex_handler_factory(),
                          validator=validate_functionapp)
         g.custom_command('list-runtimes', 'list_function_app_runtimes')
-        g.custom_command('list-flexconsumption-runtimes', 'list_flexconsumption_runtimes')
+        g.custom_command('list-flexconsumption-runtimes', 'list_flex_function_app_runtimes')
         g.custom_command('list', 'list_function_app', table_transformer=transform_web_list_output)
         g.custom_show_command('show', 'show_functionapp', table_transformer=transform_web_output)
         g.custom_command('delete', 'delete_function_app')
