@@ -69,9 +69,6 @@ class ContainerAppEnvDecorator(BaseResource):
     def get_argument_infrastructure_subnet_resource_id(self):
         return self.get_param("infrastructure_subnet_resource_id")
 
-    def get_argument_docker_bridge_cidr(self):
-        return self.get_param("docker_bridge_cidr")
-
     def get_argument_platform_reserved_cidr(self):
         return self.get_param("platform_reserved_cidr")
 
@@ -251,15 +248,12 @@ class ContainerAppEnvCreateDecorator(ContainerAppEnvDecorator):
         self.managed_env_def["properties"]["appLogsConfiguration"] = app_logs_config_def
 
     def set_up_vnet_configuration(self):
-        if self.get_argument_infrastructure_subnet_resource_id() or self.get_argument_docker_bridge_cidr() or self.get_argument_platform_reserved_cidr() or self.get_argument_platform_reserved_dns_ip():
+        if self.get_argument_infrastructure_subnet_resource_id() or self.get_argument_platform_reserved_cidr() or self.get_argument_platform_reserved_dns_ip():
             vnet_config_def = VnetConfigurationModel
 
             if self.get_argument_infrastructure_subnet_resource_id() is not None:
                 vnet_config_def["infrastructureSubnetId"] = self.get_argument_infrastructure_subnet_resource_id()
 
-            if self.get_argument_docker_bridge_cidr() is not None:
-                vnet_config_def["dockerBridgeCidr"] = self.get_argument_docker_bridge_cidr()
-
             if self.get_argument_platform_reserved_cidr() is not None:
                 vnet_config_def["platformReservedCidr"] = self.get_argument_platform_reserved_cidr()
 
