@@ -30,7 +30,8 @@ def load_arguments(self, _):
     from ._completers import subnet_completion_list, cluster_admin_account_completion_list, \
         cluster_user_group_completion_list, get_resource_name_completion_list_under_subscription
     from knack.arguments import CLIArgumentType
-    from azure.mgmt.hdinsight.models import Tier, JsonWebKeyEncryptionAlgorithm, ResourceProviderConnection
+    from azure.mgmt.hdinsight.models import Tier, JsonWebKeyEncryptionAlgorithm
+    from azure.mgmt.hdinsight.models import ResourceProviderConnection, OutboundDependenciesManagedType
     from argcomplete.completers import FilesCompleter
     node_size_type = CLIArgumentType(arg_group='Node',
                                      help='The size of the node. See also: https://docs.microsoft.com/azure/'
@@ -227,6 +228,17 @@ def load_arguments(self, _):
                    arg_type=get_enum_type(ResourceProviderConnection), help='The resource provider connection type')
         c.argument('enable_private_link', arg_group='Private Link', arg_type=get_three_state_flag(),
                    help='Indicate whether enable the private link or not.')
+        c.argument('outbound_dependencies_managed_type',
+                   options_list=['--outbound-dependencies-managed-type', '--outbound-managed-type'],
+                   arg_group='Private Link',
+                   arg_type=get_enum_type(OutboundDependenciesManagedType),
+                   help='The direction for the resource provider connection.')
+
+        c.argument('public_ip_tag_type', arg_group='Private Link',
+                   help='Gets or sets the ipTag type: Example FirstPartyUsage.')
+        c.argument('public_ip_tag_value', arg_group='Private Link',
+                   help='Gets or sets value of the IpTag associated with the public IP.'
+                   'Example HDInsight, SQL, Storage etc')
 
         c.argument('private_link_configurations',
                    options_list=['--private-link-config', '--private-link-configurations'],
@@ -252,6 +264,14 @@ def load_arguments(self, _):
             c.argument('target_instance_count', options_list=['--workernode-count', '-c'],
                        help='The target worker node instance count for the operation.', required=True)
 
+        # update
+        with self.argument_context('hdinsight update') as c:
+            c.argument('tags', tags_type)
+            c.argument('assign_identity', arg_group='Managed Service Identity', validator=validate_msi,
+                       completer=get_resource_name_completion_list_under_subscription(
+                           'Microsoft.ManagedIdentity/userAssignedIdentities'),
+                       help="The name or ID of user assigned identity.")
+
         # application
         with self.argument_context('hdinsight application') as c:
             c.argument('cluster_name', options_list=['--cluster-name'],
@@ -317,6 +337,16 @@ def load_arguments(self, _):
                                            'Required when workspace ID is provided.')
             c.ignore('workspace_type')
 
+        # Azure Monitor Agent
+        with self.argument_context('hdinsight azure-monitor-agent') as c:
+            c.argument('workspace', validator=validate_workspace,
+                       completer=get_resource_name_completion_list_under_subscription(
+                           'Microsoft.OperationalInsights/workspaces'),
+                       help='The name, resource ID or workspace ID of Log Analytics workspace.')
+            c.argument('primary_key', help='The certificate for the Log Analytics workspace. '
+                                           'Required when workspace ID is provided.')
+            c.ignore('workspace_type')
+
         with self.argument_context('hdinsight host') as c:
             c.argument('cluster_name', options_list=['--cluster-name'],
                        completer=get_resource_name_completion_list('Microsoft.HDInsight/clusters'),
